*********
Changelog
*********

v0.1.0
========================================

- Threaded album art retrival to avoid locking up frontend
- BugFix: fixed typo in album art retry functionality
- BugFix: use time.sleep instead of event.wait, which was returning immediately


v0.0.2
========================================

- Depend upon musicbrainzngs


v0.0.1
========================================

- Initial release.
